# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.invoices_resource import InvoicesResource

class TestInvoicesResource(unittest.TestCase):
    """InvoicesResource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoicesResource:
        """Test InvoicesResource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoicesResource`
        """
        model = InvoicesResource()
        if include_optional:
            return InvoicesResource(
                id = '37',
                type = 'invoices',
                attributes = jubladb_api.models.invoices.invoices(
                    title = '', 
                    description = '', 
                    state = '', 
                    group_id = 56, 
                    recipient_id = 56, 
                    due_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    issued_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    recipient_email = '', 
                    payment_information = '', 
                    payment_purpose = '', 
                    hide_total = True, ),
                relationships = jubladb_api.models.invoices_relationships.invoices_relationships(
                    group = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                        links = { }, 
                        data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                            type = 'additional_emails', 
                            meta = { }, 
                            id = '44', ), 
                        meta = { }, ), 
                    recipient = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(), 
                    invoice_items = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), ),
                links = {
                    'key' : null
                    }
            )
        else:
            return InvoicesResource(
        )
        """

    def testInvoicesResource(self):
        """Test InvoicesResource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.api.event_kind_categories_api import EventKindCategoriesApi


class TestEventKindCategoriesApi(unittest.TestCase):
    """EventKindCategoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventKindCategoriesApi()

    def tearDown(self) -> None:
        pass

    def test_get_event_kind_category(self) -> None:
        """Test case for get_event_kind_category

        Fetch Event kind category
        """
        pass

    def test_list_event_kind_categories(self) -> None:
        """Test case for list_event_kind_categories

        List Event kind categories
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from jubladb_api.models.event_kind_categories_collection import EventKindCategoriesCollection
from jubladb_api.models.event_kind_categories_readable_attribute import EventKindCategoriesReadableAttribute
from jubladb_api.models.event_kind_categories_single import EventKindCategoriesSingle

from jubladb_api.api_client import ApiClient, RequestSerialized
from jubladb_api.api_response import ApiResponse
from jubladb_api.rest import RESTResponseType


class EventKindCategoriesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_event_kind_category(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_event_kind_categories: Annotated[Optional[List[EventKindCategoriesReadableAttribute]], Field(description="[Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> EventKindCategoriesSingle:
        """Fetch Event kind category


        :param id: ID of the resource (required)
        :type id: str
        :param sort: [Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_event_kind_categories: [Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_event_kind_categories: List[EventKindCategoriesReadableAttribute]
        :param filter_id_eq: [Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_event_kind_category_serialize(
            id=id,
            sort=sort,
            fields_event_kind_categories=fields_event_kind_categories,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EventKindCategoriesSingle",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_event_kind_category_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_event_kind_categories: Annotated[Optional[List[EventKindCategoriesReadableAttribute]], Field(description="[Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> ApiResponse[EventKindCategoriesSingle]:
        """Fetch Event kind category


        :param id: ID of the resource (required)
        :type id: str
        :param sort: [Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_event_kind_categories: [Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_event_kind_categories: List[EventKindCategoriesReadableAttribute]
        :param filter_id_eq: [Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_event_kind_category_serialize(
            id=id,
            sort=sort,
            fields_event_kind_categories=fields_event_kind_categories,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EventKindCategoriesSingle",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_event_kind_category_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of the resource")],
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_event_kind_categories: Annotated[Optional[List[EventKindCategoriesReadableAttribute]], Field(description="[Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RESTResponseType:
        """Fetch Event kind category


        :param id: ID of the resource (required)
        :type id: str
        :param sort: [Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_event_kind_categories: [Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_event_kind_categories: List[EventKindCategoriesReadableAttribute]
        :param filter_id_eq: [Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_event_kind_category_serialize(
            id=id,
            sort=sort,
            fields_event_kind_categories=fields_event_kind_categories,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EventKindCategoriesSingle",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
            '404': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_event_kind_category_serialize(
        self,
        id,
        sort,
        fields_event_kind_categories,
        filter_id_eq,
        filter_id_not_eq,
        filter_id_gt,
        filter_id_gte,
        filter_id_lt,
        filter_id_lte,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sort': 'csv',
            'fields[event_kind_categories]': 'csv',
            'filter[id][eq]': 'csv',
            'filter[id][not_eq]': 'csv',
            'filter[id][gt]': 'csv',
            'filter[id][gte]': 'csv',
            'filter[id][lt]': 'csv',
            'filter[id][lte]': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters

        if _additional_query_params is not None:
            _query_params.extend((key, value) for key, value in _additional_query_params.items())

        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if fields_event_kind_categories is not None:
            
            _query_params.append(('fields[event_kind_categories]', fields_event_kind_categories))
            
        if filter_id_eq is not None:
            
            _query_params.append(('filter[id][eq]', filter_id_eq))
            
        if filter_id_not_eq is not None:
            
            _query_params.append(('filter[id][not_eq]', filter_id_not_eq))
            
        if filter_id_gt is not None:
            
            _query_params.append(('filter[id][gt]', filter_id_gt))
            
        if filter_id_gte is not None:
            
            _query_params.append(('filter[id][gte]', filter_id_gte))
            
        if filter_id_lt is not None:
            
            _query_params.append(('filter[id][lt]', filter_id_lt))
            
        if filter_id_lte is not None:
            
            _query_params.append(('filter[id][lte]', filter_id_lte))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/vnd.api+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ServiceTokenAuthHeader', 
            'ServiceTokenAuthParam'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/event_kind_categories/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_event_kind_categories(
        self,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_event_kind_categories: Annotated[Optional[List[EventKindCategoriesReadableAttribute]], Field(description="[Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> EventKindCategoriesCollection:
        """List Event kind categories


        :param sort: [Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_event_kind_categories: [Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_event_kind_categories: List[EventKindCategoriesReadableAttribute]
        :param filter_id_eq: [Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_event_kind_categories_serialize(
            sort=sort,
            fields_event_kind_categories=fields_event_kind_categories,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EventKindCategoriesCollection",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_event_kind_categories_with_http_info(
        self,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_event_kind_categories: Annotated[Optional[List[EventKindCategoriesReadableAttribute]], Field(description="[Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> ApiResponse[EventKindCategoriesCollection]:
        """List Event kind categories


        :param sort: [Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_event_kind_categories: [Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_event_kind_categories: List[EventKindCategoriesReadableAttribute]
        :param filter_id_eq: [Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_event_kind_categories_serialize(
            sort=sort,
            fields_event_kind_categories=fields_event_kind_categories,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EventKindCategoriesCollection",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_event_kind_categories_without_preload_content(
        self,
        sort: Annotated[Optional[List[StrictStr]], Field(description="[Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  ")] = None,
        fields_event_kind_categories: Annotated[Optional[List[EventKindCategoriesReadableAttribute]], Field(description="[Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)")] = None,
        filter_id_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_not_eq: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_gte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lt: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        filter_id_lte: Annotated[Optional[List[StrictInt]], Field(description="[Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RESTResponseType:
        """List Event kind categories


        :param sort: [Sort event_kind_categories according to one or more criteria](https://jsonapi.org/format/#fetching-sorting)  You should not include both ascending `id` and descending `-id` fields the same time  
        :type sort: List[str]
        :param fields_event_kind_categories: [Include only specified fields of Kind category in response](https://jsonapi.org/format/#fetching-sparse-fieldsets)
        :type fields_event_kind_categories: List[EventKindCategoriesReadableAttribute]
        :param filter_id_eq: [Filter Kind category by id using eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_eq: List[int]
        :param filter_id_not_eq: [Filter Kind category by id using not_eq operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_not_eq: List[int]
        :param filter_id_gt: [Filter Kind category by id using gt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gt: List[int]
        :param filter_id_gte: [Filter Kind category by id using gte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_gte: List[int]
        :param filter_id_lt: [Filter Kind category by id using lt operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lt: List[int]
        :param filter_id_lte: [Filter Kind category by id using lte operator](https://jsonapi.org/format/#fetching-filtering)
        :type filter_id_lte: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_event_kind_categories_serialize(
            sort=sort,
            fields_event_kind_categories=fields_event_kind_categories,
            filter_id_eq=filter_id_eq,
            filter_id_not_eq=filter_id_not_eq,
            filter_id_gt=filter_id_gt,
            filter_id_gte=filter_id_gte,
            filter_id_lt=filter_id_lt,
            filter_id_lte=filter_id_lte,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
            _additional_query_params=_additional_query_params,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "EventKindCategoriesCollection",
            '401': "JsonapiFailure",
            '403': "JsonapiFailure",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_event_kind_categories_serialize(
        self,
        sort,
        fields_event_kind_categories,
        filter_id_eq,
        filter_id_not_eq,
        filter_id_gt,
        filter_id_gte,
        filter_id_lt,
        filter_id_lte,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
        _additional_query_params: Optional[Dict[StrictStr, Any]] = None,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sort': 'csv',
            'fields[event_kind_categories]': 'csv',
            'filter[id][eq]': 'csv',
            'filter[id][not_eq]': 'csv',
            'filter[id][gt]': 'csv',
            'filter[id][gte]': 'csv',
            'filter[id][lt]': 'csv',
            'filter[id][lte]': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters

        if _additional_query_params is not None:
            _query_params.extend((key, value) for key, value in _additional_query_params.items())

        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if fields_event_kind_categories is not None:
            
            _query_params.append(('fields[event_kind_categories]', fields_event_kind_categories))
            
        if filter_id_eq is not None:
            
            _query_params.append(('filter[id][eq]', filter_id_eq))
            
        if filter_id_not_eq is not None:
            
            _query_params.append(('filter[id][not_eq]', filter_id_not_eq))
            
        if filter_id_gt is not None:
            
            _query_params.append(('filter[id][gt]', filter_id_gt))
            
        if filter_id_gte is not None:
            
            _query_params.append(('filter[id][gte]', filter_id_gte))
            
        if filter_id_lt is not None:
            
            _query_params.append(('filter[id][lt]', filter_id_lt))
            
        if filter_id_lte is not None:
            
            _query_params.append(('filter[id][lte]', filter_id_lte))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/vnd.api+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ServiceTokenAuthHeader', 
            'ServiceTokenAuthParam'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/event_kind_categories',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from jubladb_api.models.jsonapi_error_source import JsonapiErrorSource
from jubladb_api.models.jsonapi_link import JsonapiLink
from typing import Optional, Set
from typing_extensions import Self

class JsonapiError(BaseModel):
    """
    JsonapiError
    """ # noqa: E501
    links: Optional[Dict[str, JsonapiLink]] = None
    status: Optional[StrictStr] = Field(default=None, description="The HTTP status code applicable to this problem, expressed as a string value.")
    code: Optional[StrictStr] = Field(default=None, description="An application-specific error code, expressed as a string value.")
    title: Optional[StrictStr] = Field(default=None, description="A short, human-readable summary of the problem. It **SHOULD NOT** change from occurrence to occurrence of the problem, except for purposes of localization.")
    detail: Optional[StrictStr] = Field(default=None, description="A human-readable explanation specific to this occurrence of the problem.")
    source: Optional[JsonapiErrorSource] = None
    meta: Optional[Dict[str, Any]] = Field(default=None, description="Non-standard meta-information that can not be represented as an attribute or relationship.")
    __properties: ClassVar[List[str]] = ["links", "status", "code", "title", "detail", "source", "meta"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of JsonapiError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in links (dict)
        _field_dict = {}
        if self.links:
            for _key_links in self.links:
                if self.links[_key_links]:
                    _field_dict[_key_links] = self.links[_key_links].to_dict()
            _dict['links'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # set to None if links (nullable) is None
        # and model_fields_set contains the field
        if self.links is None and "links" in self.model_fields_set:
            _dict['links'] = None

        # set to None if meta (nullable) is None
        # and model_fields_set contains the field
        if self.meta is None and "meta" in self.model_fields_set:
            _dict['meta'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of JsonapiError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "links": dict(
                (_k, JsonapiLink.from_dict(_v))
                for _k, _v in obj["links"].items()
            )
            if obj.get("links") is not None
            else None,
            "status": obj.get("status"),
            "code": obj.get("code"),
            "title": obj.get("title"),
            "detail": obj.get("detail"),
            "source": JsonapiErrorSource.from_dict(obj["source"]) if obj.get("source") is not None else None,
            "meta": obj.get("meta")
        })
        return _obj





# flake8: noqa

# import apis into api package
from jubladb_api.api.event_kind_categories_api import EventKindCategoriesApi
from jubladb_api.api.event_kinds_api import EventKindsApi
from jubladb_api.api.events_api import EventsApi
from jubladb_api.api.groups_api import GroupsApi
from jubladb_api.api.invoices_api import InvoicesApi
from jubladb_api.api.people_api import PeopleApi
from jubladb_api.api.roles_api import RolesApi




# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.event_kinds import EventKinds

class TestEventKinds(unittest.TestCase):
    """EventKinds unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventKinds:
        """Test EventKinds
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventKinds`
        """
        model = EventKinds()
        if include_optional:
            return EventKinds(
                label = '',
                short_name = '',
                general_information = '',
                application_conditions = '',
                minimum_age = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return EventKinds(
        )
        """

    def testEventKinds(self):
        """Test EventKinds"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.event_kinds_relationships import EventKindsRelationships

class TestEventKindsRelationships(unittest.TestCase):
    """EventKindsRelationships unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventKindsRelationships:
        """Test EventKindsRelationships
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventKindsRelationships`
        """
        model = EventKindsRelationships()
        if include_optional:
            return EventKindsRelationships(
                kind_category = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                    links = { }, 
                    data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                        type = 'additional_emails', 
                        meta = { }, 
                        id = '44', ), 
                    meta = { }, )
            )
        else:
            return EventKindsRelationships(
        )
        """

    def testEventKindsRelationships(self):
        """Test EventKindsRelationships"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



import urllib.parse
from typing import Callable, Any, Optional, Dict, Iterator

import jubladb_api

def _iterate(list_func: Callable[[Dict[str, Any]], Any]):
    chunk = list_func({})
    while chunk is not None:
        yield from chunk.data
        if chunk.links is not None and chunk.links.next is not None:
            next_query = urllib.parse.parse_qs(urllib.parse.urlparse(chunk.links.next.actual_instance).query)
            keeping_query = {key: value[0] for key, value in next_query.items() if key in ["page[number]", "page[size]"]}

            chunk = list_func({"_additional_query_params": keeping_query})
        else:
            chunk = None

def iterate_event_kinds(api: jubladb_api.EventKindsApi, **kwargs) -> Iterator[jubladb_api.EventKindsResource]:
    return _iterate(lambda kwargs2: api.list_event_kinds(**kwargs, **kwargs2))

def iterate_events(api: jubladb_api.EventsApi, **kwargs) -> Iterator[jubladb_api.EventsResource]:
    return _iterate(lambda kwargs2: api.list_events(**kwargs, **kwargs2))

def iterate_groups(api: jubladb_api.GroupsApi, **kwargs) -> Iterator[jubladb_api.GroupsResource]:
    return _iterate(lambda kwargs2: api.list_groups(**kwargs, **kwargs2))

def iterate_invoices(api: jubladb_api.InvoicesApi, **kwargs) -> Iterator[jubladb_api.InvoicesResource]:
    return _iterate(lambda kwargs2: api.list_invoices(**kwargs, **kwargs2))

def iterate_people(api: jubladb_api.PeopleApi, **kwargs) -> Iterator[jubladb_api.PeopleResource]:
    return _iterate(lambda kwargs2: api.list_people(**kwargs, **kwargs2))

def iterate_roles(api: jubladb_api.RolesApi, **kwargs) -> Iterator[jubladb_api.RolesResource]:
    return _iterate(lambda kwargs2: api.list_roles(**kwargs, **kwargs2))


# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.jsonapi_linkage import JsonapiLinkage

class TestJsonapiLinkage(unittest.TestCase):
    """JsonapiLinkage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsonapiLinkage:
        """Test JsonapiLinkage
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsonapiLinkage`
        """
        model = JsonapiLinkage()
        if include_optional:
            return JsonapiLinkage(
                type = 'additional_emails',
                meta = { },
                id = '44'
            )
        else:
            return JsonapiLinkage(
                type = 'additional_emails',
                id = '44',
        )
        """

    def testJsonapiLinkage(self):
        """Test JsonapiLinkage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.people_collection import PeopleCollection

class TestPeopleCollection(unittest.TestCase):
    """PeopleCollection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PeopleCollection:
        """Test PeopleCollection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PeopleCollection`
        """
        model = PeopleCollection()
        if include_optional:
            return PeopleCollection(
                data = [
                    jubladb_api.models.people_resource.people_resource(
                        id = '99', 
                        type = 'people', 
                        attributes = jubladb_api.models.people.people(
                            first_name = '', 
                            last_name = '', 
                            nickname = '', 
                            company_name = '', 
                            company = True, 
                            email = '', 
                            address = '', 
                            zip_code = '', 
                            town = '', 
                            country = '', 
                            primary_group_id = 56, 
                            gender = '', 
                            birthday = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            language = '', ), 
                        relationships = jubladb_api.models.people_relationships.people_relationships(
                            primary_group = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                                links = { }, 
                                data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                                    type = 'additional_emails', 
                                    meta = { }, 
                                    id = '44', ), 
                                meta = { }, ), 
                            layer_group = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(), 
                            roles = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), 
                            phone_numbers = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), 
                            social_accounts = , 
                            additional_emails = , ), 
                        links = {
                            'key' : null
                            }, )
                    ],
                included = [
                    jubladb_api.models.jsonapi_resource.jsonapi_resource()
                    ],
                meta = { },
                links = None,
                jsonapi = jubladb_api.models.jsonapi_jsonapi.jsonapi_jsonapi(
                    version = '1.0', 
                    meta = { }, )
            )
        else:
            return PeopleCollection(
        )
        """

    def testPeopleCollection(self):
        """Test PeopleCollection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.people import People

class TestPeople(unittest.TestCase):
    """People unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> People:
        """Test People
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `People`
        """
        model = People()
        if include_optional:
            return People(
                first_name = '',
                last_name = '',
                nickname = '',
                company_name = '',
                company = True,
                email = '',
                address = '',
                zip_code = '',
                town = '',
                country = '',
                primary_group_id = 56,
                gender = '',
                birthday = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                language = ''
            )
        else:
            return People(
        )
        """

    def testPeople(self):
        """Test People"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.social_accounts_single import SocialAccountsSingle

class TestSocialAccountsSingle(unittest.TestCase):
    """SocialAccountsSingle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SocialAccountsSingle:
        """Test SocialAccountsSingle
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SocialAccountsSingle`
        """
        model = SocialAccountsSingle()
        if include_optional:
            return SocialAccountsSingle(
                data = jubladb_api.models.social_accounts_resource.social_accounts_resource(
                    id = '90', 
                    type = 'social_accounts', 
                    attributes = jubladb_api.models.social_accounts.social_accounts(
                        label = '', 
                        public = True, 
                        contactable_id = 56, 
                        contactable_type = '', 
                        name = '', ), 
                    relationships = jubladb_api.models.relationships.relationships(), 
                    links = {
                        'key' : null
                        }, ),
                included = [
                    jubladb_api.models.jsonapi_resource.jsonapi_resource()
                    ],
                meta = { },
                links = None,
                jsonapi = jubladb_api.models.jsonapi_jsonapi.jsonapi_jsonapi(
                    version = '1.0', 
                    meta = { }, )
            )
        else:
            return SocialAccountsSingle(
        )
        """

    def testSocialAccountsSingle(self):
        """Test SocialAccountsSingle"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class EventsReadableAttribute(str, Enum):
    """
    Event readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    GROUP_IDS = 'group_ids'
    TYPE = 'type'
    KIND_ID = 'kind_id'
    NAME = 'name'
    DESCRIPTION = 'description'
    APPLICATION_CONDITIONS = 'application_conditions'
    MOTTO = 'motto'
    COST = 'cost'
    LOCATION = 'location'
    APPLICATION_OPENING_AT = 'application_opening_at'
    APPLICATION_CLOSING_AT = 'application_closing_at'
    APPLICATION_CONTACT_ID = 'application_contact_id'
    EXTERNAL_APPLICATION_LINK = 'external_application_link'
    MAXIMUM_PARTICIPANTS = 'maximum_participants'
    CREATED_AT = 'created_at'
    UPDATED_AT = 'updated_at'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EventsReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.roles_readable_attribute import RolesReadableAttribute

class TestRolesReadableAttribute(unittest.TestCase):
    """RolesReadableAttribute unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRolesReadableAttribute(self):
        """Test RolesReadableAttribute"""
        # inst = RolesReadableAttribute()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class InvoiceItemsReadableAttribute(str, Enum):
    """
    Invoice item readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    INVOICE_ID = 'invoice_id'
    NAME = 'name'
    DESCRIPTION = 'description'
    UNIT_COST = 'unit_cost'
    VAT_RATE = 'vat_rate'
    COST = 'cost'
    COUNT = 'count'
    COST_CENTER = 'cost_center'
    ACCOUNT = 'account'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of InvoiceItemsReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from jubladb_api.models.additional_emails_resource import AdditionalEmailsResource
from jubladb_api.models.courses_resource import CoursesResource
from jubladb_api.models.dates_resource import DatesResource
from jubladb_api.models.event_kind_categories_resource import EventKindCategoriesResource
from jubladb_api.models.event_kinds_resource import EventKindsResource
from jubladb_api.models.events_resource import EventsResource
from jubladb_api.models.groups_resource import GroupsResource
from jubladb_api.models.invoice_items_resource import InvoiceItemsResource
from jubladb_api.models.invoices_resource import InvoicesResource
from jubladb_api.models.people_resource import PeopleResource
from jubladb_api.models.person_name_resource import PersonNameResource
from jubladb_api.models.phone_numbers_resource import PhoneNumbersResource
from jubladb_api.models.roles_resource import RolesResource
from jubladb_api.models.social_accounts_resource import SocialAccountsResource
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

JSONAPIRESOURCE_ONE_OF_SCHEMAS = ["AdditionalEmailsResource", "CoursesResource", "DatesResource", "EventKindCategoriesResource", "EventKindsResource", "EventsResource", "GroupsResource", "InvoiceItemsResource", "InvoicesResource", "PeopleResource", "PersonNameResource", "PhoneNumbersResource", "RolesResource", "SocialAccountsResource"]

class JsonapiResource(BaseModel):
    """
    JsonapiResource
    """
    # data type: AdditionalEmailsResource
    oneof_schema_1_validator: Optional[AdditionalEmailsResource] = None
    # data type: CoursesResource
    oneof_schema_2_validator: Optional[CoursesResource] = None
    # data type: DatesResource
    oneof_schema_3_validator: Optional[DatesResource] = None
    # data type: EventKindCategoriesResource
    oneof_schema_4_validator: Optional[EventKindCategoriesResource] = None
    # data type: EventKindsResource
    oneof_schema_5_validator: Optional[EventKindsResource] = None
    # data type: EventsResource
    oneof_schema_6_validator: Optional[EventsResource] = None
    # data type: GroupsResource
    oneof_schema_7_validator: Optional[GroupsResource] = None
    # data type: InvoiceItemsResource
    oneof_schema_8_validator: Optional[InvoiceItemsResource] = None
    # data type: InvoicesResource
    oneof_schema_9_validator: Optional[InvoicesResource] = None
    # data type: PersonNameResource
    oneof_schema_10_validator: Optional[PersonNameResource] = None
    # data type: PeopleResource
    oneof_schema_11_validator: Optional[PeopleResource] = None
    # data type: PhoneNumbersResource
    oneof_schema_12_validator: Optional[PhoneNumbersResource] = None
    # data type: RolesResource
    oneof_schema_13_validator: Optional[RolesResource] = None
    # data type: SocialAccountsResource
    oneof_schema_14_validator: Optional[SocialAccountsResource] = None
    actual_instance: Optional[Union[AdditionalEmailsResource, CoursesResource, DatesResource, EventKindCategoriesResource, EventKindsResource, EventsResource, GroupsResource, InvoiceItemsResource, InvoicesResource, PeopleResource, PersonNameResource, PhoneNumbersResource, RolesResource, SocialAccountsResource]] = None
    one_of_schemas: Set[str] = { "AdditionalEmailsResource", "CoursesResource", "DatesResource", "EventKindCategoriesResource", "EventKindsResource", "EventsResource", "GroupsResource", "InvoiceItemsResource", "InvoicesResource", "PeopleResource", "PersonNameResource", "PhoneNumbersResource", "RolesResource", "SocialAccountsResource" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = JsonapiResource.model_construct()
        error_messages = []
        match = 0
        # validate data type: AdditionalEmailsResource
        if not isinstance(v, AdditionalEmailsResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AdditionalEmailsResource`")
        else:
            match += 1
        # validate data type: CoursesResource
        if not isinstance(v, CoursesResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `CoursesResource`")
        else:
            match += 1
        # validate data type: DatesResource
        if not isinstance(v, DatesResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `DatesResource`")
        else:
            match += 1
        # validate data type: EventKindCategoriesResource
        if not isinstance(v, EventKindCategoriesResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `EventKindCategoriesResource`")
        else:
            match += 1
        # validate data type: EventKindsResource
        if not isinstance(v, EventKindsResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `EventKindsResource`")
        else:
            match += 1
        # validate data type: EventsResource
        if not isinstance(v, EventsResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `EventsResource`")
        else:
            match += 1
        # validate data type: GroupsResource
        if not isinstance(v, GroupsResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `GroupsResource`")
        else:
            match += 1
        # validate data type: InvoiceItemsResource
        if not isinstance(v, InvoiceItemsResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `InvoiceItemsResource`")
        else:
            match += 1
        # validate data type: InvoicesResource
        if not isinstance(v, InvoicesResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `InvoicesResource`")
        else:
            match += 1
        # validate data type: PersonNameResource
        if not isinstance(v, PersonNameResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PersonNameResource`")
        else:
            match += 1
        # validate data type: PeopleResource
        if not isinstance(v, PeopleResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PeopleResource`")
        else:
            match += 1
        # validate data type: PhoneNumbersResource
        if not isinstance(v, PhoneNumbersResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PhoneNumbersResource`")
        else:
            match += 1
        # validate data type: RolesResource
        if not isinstance(v, RolesResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `RolesResource`")
        else:
            match += 1
        # validate data type: SocialAccountsResource
        if not isinstance(v, SocialAccountsResource):
            error_messages.append(f"Error! Input type `{type(v)}` is not `SocialAccountsResource`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in JsonapiResource with oneOf schemas: AdditionalEmailsResource, CoursesResource, DatesResource, EventKindCategoriesResource, EventKindsResource, EventsResource, GroupsResource, InvoiceItemsResource, InvoicesResource, PeopleResource, PersonNameResource, PhoneNumbersResource, RolesResource, SocialAccountsResource. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in JsonapiResource with oneOf schemas: AdditionalEmailsResource, CoursesResource, DatesResource, EventKindCategoriesResource, EventKindsResource, EventsResource, GroupsResource, InvoiceItemsResource, InvoicesResource, PeopleResource, PersonNameResource, PhoneNumbersResource, RolesResource, SocialAccountsResource. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into AdditionalEmailsResource
        try:
            instance.actual_instance = AdditionalEmailsResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into CoursesResource
        try:
            instance.actual_instance = CoursesResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into DatesResource
        try:
            instance.actual_instance = DatesResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into EventKindCategoriesResource
        try:
            instance.actual_instance = EventKindCategoriesResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into EventKindsResource
        try:
            instance.actual_instance = EventKindsResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into EventsResource
        try:
            instance.actual_instance = EventsResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into GroupsResource
        try:
            instance.actual_instance = GroupsResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into InvoiceItemsResource
        try:
            instance.actual_instance = InvoiceItemsResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into InvoicesResource
        try:
            instance.actual_instance = InvoicesResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into PersonNameResource
        try:
            instance.actual_instance = PersonNameResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into PeopleResource
        try:
            instance.actual_instance = PeopleResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into PhoneNumbersResource
        try:
            instance.actual_instance = PhoneNumbersResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into RolesResource
        try:
            instance.actual_instance = RolesResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into SocialAccountsResource
        try:
            instance.actual_instance = SocialAccountsResource.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into JsonapiResource with oneOf schemas: AdditionalEmailsResource, CoursesResource, DatesResource, EventKindCategoriesResource, EventKindsResource, EventsResource, GroupsResource, InvoiceItemsResource, InvoicesResource, PeopleResource, PersonNameResource, PhoneNumbersResource, RolesResource, SocialAccountsResource. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into JsonapiResource with oneOf schemas: AdditionalEmailsResource, CoursesResource, DatesResource, EventKindCategoriesResource, EventKindsResource, EventsResource, GroupsResource, InvoiceItemsResource, InvoicesResource, PeopleResource, PersonNameResource, PhoneNumbersResource, RolesResource, SocialAccountsResource. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], AdditionalEmailsResource, CoursesResource, DatesResource, EventKindCategoriesResource, EventKindsResource, EventsResource, GroupsResource, InvoiceItemsResource, InvoicesResource, PeopleResource, PersonNameResource, PhoneNumbersResource, RolesResource, SocialAccountsResource]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.courses_resource import CoursesResource

class TestCoursesResource(unittest.TestCase):
    """CoursesResource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CoursesResource:
        """Test CoursesResource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CoursesResource`
        """
        model = CoursesResource()
        if include_optional:
            return CoursesResource(
                id = '52',
                type = 'courses',
                attributes = jubladb_api.models.courses.courses(
                    group_ids = 56, 
                    type = '', 
                    kind_id = 56, 
                    name = '', 
                    description = '', 
                    application_conditions = '', 
                    motto = '', 
                    cost = '', 
                    location = '', 
                    application_opening_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    application_closing_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    application_contact_id = 56, 
                    external_application_link = '', 
                    maximum_participants = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    state = '', 
                    training_days = 1.337, 
                    applicant_count = 56, 
                    participant_count = 56, 
                    minimum_participants = 56, 
                    number = '', 
                    teamer_count = 56, ),
                relationships = jubladb_api.models.courses_relationships.courses_relationships(
                    contact = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                        links = { }, 
                        data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                            type = 'additional_emails', 
                            meta = { }, 
                            id = '44', ), 
                        meta = { }, ), 
                    kind = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(), 
                    dates = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), 
                    leaders = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), ),
                links = {
                    'key' : null
                    }
            )
        else:
            return CoursesResource(
        )
        """

    def testCoursesResource(self):
        """Test CoursesResource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.invoices_request import InvoicesRequest

class TestInvoicesRequest(unittest.TestCase):
    """InvoicesRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoicesRequest:
        """Test InvoicesRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoicesRequest`
        """
        model = InvoicesRequest()
        if include_optional:
            return InvoicesRequest(
                data = jubladb_api.models.invoices_resource.invoices_resource(
                    id = '37', 
                    type = 'invoices', 
                    attributes = jubladb_api.models.invoices.invoices(
                        title = '', 
                        description = '', 
                        state = '', 
                        group_id = 56, 
                        recipient_id = 56, 
                        due_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        issued_at = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        recipient_email = '', 
                        payment_information = '', 
                        payment_purpose = '', 
                        hide_total = True, ), 
                    relationships = jubladb_api.models.invoices_relationships.invoices_relationships(
                        group = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                            links = { }, 
                            data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                                type = 'additional_emails', 
                                meta = { }, 
                                id = '44', ), 
                            meta = { }, ), 
                        recipient = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(), 
                        invoice_items = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), ), 
                    links = {
                        'key' : null
                        }, )
            )
        else:
            return InvoicesRequest(
        )
        """

    def testInvoicesRequest(self):
        """Test InvoicesRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from jubladb_api.models.courses_relationships_contact import CoursesRelationshipsContact
from jubladb_api.models.courses_relationships_dates import CoursesRelationshipsDates
from typing import Optional, Set
from typing_extensions import Self

class PeopleRelationships(BaseModel):
    """
    PeopleRelationships
    """ # noqa: E501
    primary_group: Optional[CoursesRelationshipsContact] = None
    layer_group: Optional[CoursesRelationshipsContact] = None
    roles: Optional[CoursesRelationshipsDates] = None
    phone_numbers: Optional[CoursesRelationshipsDates] = None
    social_accounts: Optional[CoursesRelationshipsDates] = None
    additional_emails: Optional[CoursesRelationshipsDates] = None
    __properties: ClassVar[List[str]] = ["primary_group", "layer_group", "roles", "phone_numbers", "social_accounts", "additional_emails"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PeopleRelationships from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of primary_group
        if self.primary_group:
            _dict['primary_group'] = self.primary_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of layer_group
        if self.layer_group:
            _dict['layer_group'] = self.layer_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of roles
        if self.roles:
            _dict['roles'] = self.roles.to_dict()
        # override the default output from pydantic by calling `to_dict()` of phone_numbers
        if self.phone_numbers:
            _dict['phone_numbers'] = self.phone_numbers.to_dict()
        # override the default output from pydantic by calling `to_dict()` of social_accounts
        if self.social_accounts:
            _dict['social_accounts'] = self.social_accounts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of additional_emails
        if self.additional_emails:
            _dict['additional_emails'] = self.additional_emails.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PeopleRelationships from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "primary_group": CoursesRelationshipsContact.from_dict(obj["primary_group"]) if obj.get("primary_group") is not None else None,
            "layer_group": CoursesRelationshipsContact.from_dict(obj["layer_group"]) if obj.get("layer_group") is not None else None,
            "roles": CoursesRelationshipsDates.from_dict(obj["roles"]) if obj.get("roles") is not None else None,
            "phone_numbers": CoursesRelationshipsDates.from_dict(obj["phone_numbers"]) if obj.get("phone_numbers") is not None else None,
            "social_accounts": CoursesRelationshipsDates.from_dict(obj["social_accounts"]) if obj.get("social_accounts") is not None else None,
            "additional_emails": CoursesRelationshipsDates.from_dict(obj["additional_emails"]) if obj.get("additional_emails") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from jubladb_api.models.additional_emails_resource import AdditionalEmailsResource
from jubladb_api.models.additional_emails_single_links import AdditionalEmailsSingleLinks
from jubladb_api.models.jsonapi_jsonapi import JsonapiJsonapi
from jubladb_api.models.jsonapi_resource import JsonapiResource
from typing import Optional, Set
from typing_extensions import Self

class AdditionalEmailsCollection(BaseModel):
    """
    AdditionalEmailsCollection
    """ # noqa: E501
    data: Optional[List[AdditionalEmailsResource]] = None
    included: Optional[List[JsonapiResource]] = Field(default=None, description="To reduce the number of HTTP requests, servers **MAY** allow responses that include related resources along with the requested primary resources. Such responses are called \"compound documents\".")
    meta: Optional[Dict[str, Any]] = Field(default=None, description="Non-standard meta-information that can not be represented as an attribute or relationship.")
    links: Optional[AdditionalEmailsSingleLinks] = None
    jsonapi: Optional[JsonapiJsonapi] = None
    __properties: ClassVar[List[str]] = ["data", "included", "meta", "links", "jsonapi"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AdditionalEmailsCollection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item_data in self.data:
                if _item_data:
                    _items.append(_item_data.to_dict())
            _dict['data'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in included (list)
        _items = []
        if self.included:
            for _item_included in self.included:
                if _item_included:
                    _items.append(_item_included.to_dict())
            _dict['included'] = _items
        # override the default output from pydantic by calling `to_dict()` of links
        if self.links:
            _dict['links'] = self.links.to_dict()
        # override the default output from pydantic by calling `to_dict()` of jsonapi
        if self.jsonapi:
            _dict['jsonapi'] = self.jsonapi.to_dict()
        # set to None if meta (nullable) is None
        # and model_fields_set contains the field
        if self.meta is None and "meta" in self.model_fields_set:
            _dict['meta'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AdditionalEmailsCollection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "data": [AdditionalEmailsResource.from_dict(_item) for _item in obj["data"]] if obj.get("data") is not None else None,
            "included": [JsonapiResource.from_dict(_item) for _item in obj["included"]] if obj.get("included") is not None else None,
            "meta": obj.get("meta"),
            "links": AdditionalEmailsSingleLinks.from_dict(obj["links"]) if obj.get("links") is not None else None,
            "jsonapi": JsonapiJsonapi.from_dict(obj["jsonapi"]) if obj.get("jsonapi") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: info@hitobito.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from jubladb_api.models.people_resource import PeopleResource

class TestPeopleResource(unittest.TestCase):
    """PeopleResource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PeopleResource:
        """Test PeopleResource
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PeopleResource`
        """
        model = PeopleResource()
        if include_optional:
            return PeopleResource(
                id = '99',
                type = 'people',
                attributes = jubladb_api.models.people.people(
                    first_name = '', 
                    last_name = '', 
                    nickname = '', 
                    company_name = '', 
                    company = True, 
                    email = '', 
                    address = '', 
                    zip_code = '', 
                    town = '', 
                    country = '', 
                    primary_group_id = 56, 
                    gender = '', 
                    birthday = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                    language = '', ),
                relationships = jubladb_api.models.people_relationships.people_relationships(
                    primary_group = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(
                        links = { }, 
                        data = jubladb_api.models.jsonapi_linkage.jsonapi_linkage(
                            type = 'additional_emails', 
                            meta = { }, 
                            id = '44', ), 
                        meta = { }, ), 
                    layer_group = jubladb_api.models.courses_relationships_contact.courses_relationships_contact(), 
                    roles = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), 
                    phone_numbers = jubladb_api.models.courses_relationships_dates.courses_relationships_dates(), 
                    social_accounts = , 
                    additional_emails = , ),
                links = {
                    'key' : null
                    }
            )
        else:
            return PeopleResource(
        )
        """

    def testPeopleResource(self):
        """Test PeopleResource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class InvoicesReadableAttribute(str, Enum):
    """
    Invoice readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    TITLE = 'title'
    DESCRIPTION = 'description'
    STATE = 'state'
    GROUP_ID = 'group_id'
    RECIPIENT_ID = 'recipient_id'
    DUE_AT = 'due_at'
    ISSUED_AT = 'issued_at'
    RECIPIENT_EMAIL = 'recipient_email'
    PAYMENT_INFORMATION = 'payment_information'
    PAYMENT_PURPOSE = 'payment_purpose'
    HIDE_TOTAL = 'hide_total'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of InvoicesReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Hitobito JSON:API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Contact: oss@basilbader.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class GroupsReadableAttribute(str, Enum):
    """
    Group readable attributes
    """

    """
    allowed enum values
    """
    ID = 'id'
    NAME = 'name'
    SHORT_NAME = 'short_name'
    DISPLAY_NAME = 'display_name'
    DESCRIPTION = 'description'
    LAYER = 'layer'
    PARENT_ID = 'parent_id'
    LAYER_GROUP_ID = 'layer_group_id'
    TYPE = 'type'
    EMAIL = 'email'
    ADDRESS = 'address'
    ZIP_CODE = 'zip_code'
    TOWN = 'town'
    COUNTRY = 'country'
    REQUIRE_PERSON_ADD_REQUESTS = 'require_person_add_requests'
    SELF_REGISTRATION_URL = 'self_registration_url'
    ARCHIVED_AT = 'archived_at'
    CREATED_AT = 'created_at'
    UPDATED_AT = 'updated_at'
    DELETED_AT = 'deleted_at'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of GroupsReadableAttribute from a JSON string"""
        return cls(json.loads(json_str))


